@@ -1,3 +1,5 @@
+## File Name: frm_fb.R
+## File Version: 0.714
 
 ### Factored regression model
 ### Fully Bayesian estimation
@@ -20,6 +22,7 @@ frm_fb <- function(dat, dep, ind, weights=NULL, verbose=TRUE,
 		weights0 <- rep(1,N)
 	}
 	dat0 <- dat
+	
 	#*** prepare data
 	res2 <- frm_prepare_data_fb(dat=dat, dep=dep, ind=ind, weights0=weights0,
 					dat0=dat0, data_init = data_init )
@@ -32,7 +35,7 @@ frm_fb <- function(dat, dep, ind, weights=NULL, verbose=TRUE,
 	impute_vars <- res2$impute_vars
 	impute_vars_index <- res2$impute_vars_index
 	N2 <- nrow(dat)
-
+	
 	#*** prepare list of models	
 	NM <- attr(ind,"NM")		
 	ind0 <- ind
@@ -40,30 +43,28 @@ frm_fb <- function(dat, dep, ind, weights=NULL, verbose=TRUE,
 	
 	#*** fixed standard deviations
 	# ind0 <- frm_prepare_models_sigma_fixed( ind0=ind0, NM=NM, dat0=dat0, dat=dat )
-
+	
 	#*** initial estimation of models
 	res3 <- frm_fb_initial_parameters(dat=dat, ind0=ind0, data_init=data_init)	
 	ind0 <- res3$ind0	
-	
 	parms <- res3$parms
 	parms_index <- res3$parms_index
 	model_results <- res3$model_results
 	npars <- res3$npars
+	
 	#**** allocate matrices with sampled values for parameters
 	parms_mcmc <- frm_fb_init_matrices_saved_parameters( iter=iter , burnin=burnin ,
 						Nsave=Nsave, Nimp=Nimp , npars=npars, parms=parms,
-						parms_index = parms_index, predictorMatrix=predictorMatrix
-							)				
+						parms_index = parms_index, predictorMatrix=predictorMatrix )
 						
 	#**** inits objects for imputations
 	imputations_mcmc <- frm_fb_init_imputations( Nimp = Nimp, 
 							model_results=model_results,
 							iter=iter, burnin=burnin, impute_vars = impute_vars ,
 							impute_vars_index=impute_vars_index, ind_miss=ind_miss,
-							dv_vars = dv_vars, ind0=ind0, variablesMatrix=variablesMatrix	
-								)												
+							dv_vars = dv_vars, ind0=ind0, variablesMatrix=variablesMatrix)
 	#*** add additional arguments for regression functions
-	# ind0 <- frm_prepare_models_design_matrices( ind0=ind0 , dat=dat , NM=NM)							
+	# ind0 <- frm_prepare_models_design_matrices( ind0=ind0 , dat=dat , NM=NM)
 	
 	maxiter <- iter
 	iter <- 1
@@ -75,7 +76,6 @@ zz0 <- Sys.time()
 	#**** MCMC algorithm
 	while( iterate ){		
 
-#   cat("\n..........", iter , "......\n")
 		#*** sample model parameters		
 		res <- frm_fb_sample_parameters( dat=dat, ind0=ind0 , NM=NM, iter = iter,
 					weights0=weights0 , dat_resp=dat_resp, ind_resp=ind_resp,
@@ -90,7 +90,7 @@ zz0 <- Sys.time()
 					model_results=model_results, ind0=ind0, iter=iter, dat=dat )
 		imputations_mcmc <- res$imputations_mcmc
 		dat <- res$dat
-	
+		
 		#*** refreshing proposal SD for parameters and imputed values
 		if ( ( iter %% refresh == 0 ) & ( iter <= burnin ) ){	
 			ind0 <- frm_fb_mh_refresh_parameters( ind0=ind0 , acc_bounds=acc_bounds )
@@ -106,6 +106,7 @@ zz0 <- Sys.time()
 						maxiter=maxiter, mcmc_start_time=mcmc_start_time )		
 		if (iter >= maxiter){ iterate <- FALSE }	
 		iter <- iter + 1		
+		
 	}
 	#***************************************
 # cat("\n* MCMC algorithm ") ; zz1 <- Sys.time(); print(zz1-zz0) ; zz0 <- zz1		
