@@ -1,3 +1,5 @@
+## File Name: frm_fb_partable.R
+## File Version: 0.19
 
 frm_fb_partable <- function( ind0 , parms_mcmc )
 {
@@ -59,7 +61,9 @@ frm_fb_partable <- function( ind0 , parms_mcmc )
 	dfr <- data.frame("index" = 1:NP , dfr )
 	rownames(dfr) <- NULL
 	dfr <- dfr[ ! is.na( dfr$idparm ) , ]
-		
+	
+	dfr <- frm_partable_thresholds(partable=dfr)
+	
 	#--- compute statistics
 	values <- parms_mcmc$values	
 	est <- colMeans( values )
@@ -75,10 +79,13 @@ frm_fb_partable <- function( ind0 , parms_mcmc )
 	dfr[ , "upper95"] <- apply( values, 2 , stats::quantile , probs = .975 )[ind1]
 	
 	#--- convert parameter values into coda object
+	NV <- ncol(values)
+	values <- values[ , seq(NV,1,-1) ]
 	values_coda <- coda::mcmc(data= values, start = min(parms_mcmc$iter_save), 
 								end = max(parms_mcmc$iter_save) , 
 								thin = diff(parms_mcmc$iter_save)[1] )
-	
+#	colnames(values_coda) <- paste( dfr$parm )
+								
 	#--- technical summary MCMC algorithm
 	dfr2 <- dfr[ , 1:5]
 	dfr2[,"Nsampled"] <- nrow(values)
